/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.iptc.provider;

import java.util.Collection;
import java.util.Collections;
import it.tidalwave.image.metadata.IPTC;
import org.openide.loaders.DataObject;
import it.tidalwave.metadata.Metadata.FindOption;
import it.tidalwave.metadata.Metadata.StorageType;
import it.tidalwave.metadata.MetadataItemHolder;
import it.tidalwave.metadata.spi.MetadataItemEnhancer;
import it.tidalwave.metadata.spi.MetadataItemSourceSupport;
import javax.annotation.Nonnull;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class IPTCSourceMock extends MetadataItemSourceSupport<IPTC>
  {
    public IPTCSourceMock()
      {
        super(IPTC.class, "IPTCMock", StorageType.EXTERNAL);
      }
    
//    @Override - breaks with Java 5
    @Nonnull
    public Collection<? extends MetadataItemHolder<IPTC>> loadMetadataItems (final DataObject dataObject, final FindOption ... options)
      {
        final String name = dataObject.getPrimaryFile().getNameExt();
        
        if (name.contains("bad"))
          {
            return Collections.emptyList(); 
          }

        final IPTC iptc =  MetadataItemEnhancer.createEnhancedItem(new IPTC());
        iptc.setSource("..."); // set a property to make it "available"

        return Collections.singletonList(new MetadataItemHolder<IPTC>(iptc)
          {
            public boolean isAvailable() 
              {
                return get().isAvailable();
              }           
          });
      }
  }
